#!/bin/sh

#  $Revision: 1.1 $
#bcpyrght
#***************************************************************************
#* $VRTScprght: Copyright 1993 - 2001 VERITAS Software Corporation, All Rights Reserved $ *
#***************************************************************************
#ecpyrght
#
# Script used to extract and install the validate NetBackup configuration 
# utilty components.
#
# install_NCVU.sh
#
# Usage:
# install_NCVU.sh

answer="no"

while [ "$answer" != "1" ] && [ "$answer" != "2" ]
do
  clear
  echo "Welcome to the validate NetBackup configuration installation program.\n"
  echo "Please select the method of installation that you would like to use.\n"
  echo "1.  Extract utility components and manually update the NCVU"
  echo "    file with the appropriate path to Perl version 5.003.\n"
  echo "2.  Extract utility components and the installation script will:\n"
  echo "      A.  Prompt for the directory location to search for copies of"
  echo "          PERL.\n"
  echo "      B.  Locate any copies of Perl 5.003 that exist beneath the root"
  echo "          directory.\n"
  echo "      C.  Prompt for the verification of which copy of Perl to use.\n"
  echo "      D.  Extract the utility components and update the NCVU file with"
  echo "          the path to the selected copy of Perl.\n\n"
  echo "Once the utility components are extracted, read the README file for"
  echo "instructions on how to run NCVU.\n\n"
  echo "          Selection [1/2] \c"

  read answer
done

case "$answer" in
1)
  tar -xvf NCVU_scripts.tar

  if [ ! -x NCVU ]
  then
    /usr/bin/chmod u+x NCVU
  fi

  if [ ! -x NCVU_media_server ]
  then
    /usr/bin/chmod u+x NCVU_media_server
  fi

  if [ ! -x NCVU_client ]
  then
    /usr/bin/chmod u+x NCVU_client
  fi

  exit
;;
2)
 echo "\nPlease enter the absolute path for the installation script to search for"
 echo "PERL version 5.003 or greater:\n"

 read path

 echo "\nSearching for PERL beginning at:\n"
 echo "${path}"

 find ${path} -name perl -print > temp.list
;;
esac

echo "\nChecking located copies of perl for minimum version requirements."

cat temp.list | while read path_perl
do
  version=`${path_perl} -version |egrep "This is perl"|awk -F" " '{printf("%s",substr ($5,1,5))}'`
  status=$?

  if [ "$status" = 0 ]
  then
    if [ "$version" -ge "5.003" ]
    then
      echo "$path_perl" >> perl.list
    fi
  fi
done

number_files=`wc -l perl.list|sed s/perl.list//|sed s/\ *//`

if [ "$number_files" -gt "0" ]
then
  echo "\nThe install script will now list the copies of Perl version 5.003 or"
  echo "higher that were located.  Once you have determined the copy you wish"
  echo "to use to run the NCVU utility, enter the number associated with your"
  echo "selection, n to continue listing any subsequent copies of Perl"
  echo "or q to quit.\n"

  i=1

  for perl_path in `cat perl.list`
  do
    echo "$i\t$perl_path"
    line=`expr "$i" % 22`

    if [ "$i" -lt 10 ]
    then
      first_digit=$i
    elif [ "$i" -lt 100 ]
    then
      first_digit=`echo "$i"|awk -F" " '{printf("%s",substr($0,2,2))}'`
      second_digit=`echo "$i"|awk -F" " '{printf("%s",substr($0,1,1))}'`
    fi 

    if [ $line -eq 0 ]
    then
      valid_selection="no"
      echo ""

      while [ "$valid_selection" = "no" ]
      do
        echo "          Selection [#/n/q] \c"
        read answer
        answer=`echo "$answer" |tr A-Z a-z`

        if [ "$i" -lt 10 ]
        then
          case "$answer" in
          q) 
            exit ;;
          n)
            valid_selection="next"
            clear;;
          [1-$first_digit])
            echo "selected number = $answer"
            valid_selection="yes";;
          *) 
            ;;
          esac
        elif [ "$i" -lt 100 ]
        then
          case "$answer" in
          q) 
            exit ;;
          n)
            valid_selection="next"
            clear;;
          [1-`expr "$second_digit" - 1`][0-9])
            valid_selection="yes";;
          [1-$second_digit][0-$first_digit])
            valid_selection="yes";;
          [1-9])
            valid_selection="yes";;
          *) 
            ;;
          esac
        fi
      done
    fi

    if [ "$valid_selection" = "yes" ]
    then
      break
    fi

    if [ "$i" -eq "$number_files" ]
    then
      break
    fi

    i=`expr "$i" + 1`
  done

  while [ "$valid_selection" != "yes" ]
  do
    echo "         Selection [#/q] \c"
    read answer
    answer=`echo "$answer" |tr A-Z a-z`

    if [ "$i" -lt 10 ]
    then
      first_digit=$i
    elif [ "$i" -lt 100 ]
    then
      first_digit=`echo "$i"|awk -F" " '{printf("%s",substr($0,2,2))}'`
      second_digit=`echo "$i"|awk -F" " '{printf("%s",substr($0,1,1))}'`
    fi 
    
    if [ "$i" -lt 10 ]
    then
      case "$answer" in
      q) 
        exit ;;
      [1-$first_digit])
        valid_selection="yes";;
      *) 
        ;;
      esac
    elif [ "$i" -lt 100 ]
    then
      case "$answer" in
      q) 
        exit ;;
      [1-`expr "$second_digit" - 1`][0-9])
        valid_selection="yes";;
      [1-$second_digit][0-$first_digit])
        valid_selection="yes";;
      [1-9])
        valid_selection="yes";;
      *) 
        ;;
      esac
    fi
  done

  i=1

  echo "\nUntarring and updating NCVU components.\n"

  for perl_path in `cat perl.list`
  do
    if [ "$i" -eq "$answer" ]
    then
      tar -xvf NCVU_scripts.tar
      echo "#!\c" > temp.file
      echo "$perl_path" >> temp.file
      cat NCVU >> temp.file
      mv temp.file NCVU
      rm perl.list temp.list

      if [ ! -x NCVU ]
      then
        /usr/bin/chmod u+x NCVU
      fi

      if [ ! -x NCVU_media_server ]
      then
        /usr/bin/chmod u+x NCVU_media_server
      fi
    
      if [ ! -x NCVU_client ]
      then
        /usr/bin/chmod u+x NCVU_client
      fi

      break
    else
      i=`expr "$i" + 1`
    fi
  done
else
  echo "There were no copies of Perl found that were version 5.003 or higher."
  echo "Please install Perl version 5.003 or higher and run the installation"
  echo "script again."
  exit 1
fi
